@@ -21,7 +21,7 @@ test2=subset(outdata,outdata$RCH==3)
 test2$mdate=as.Date(row(test2)[,1],origin=paste(start_year-1,"-12-31",sep=""))
 test3=merge(flowgage$flowdata,test2[c(2,length(test2))],all=F)
 test3$Qm3ps=test3$flow/3600/24
-NS=NSeff(test3$Qm3ps, test3$FLOW_OUTcms)
+NS = NSeff(test3$Qm3ps[730:(length(test3$Qm3ps))], test3$FLOW_OUTcms[730:(length(test3$Qm3ps))])
 plot(test3$mdate, test3$Qm3ps,type="l")
 lines(test3$mdate, test3$FLOW_OUTcms,col="red")
 print(NS)
